@@ -6,12 +6,16 @@
  * @license   http://www.opensource.org/licenses/mit-license.html  MIT License
  */
 
+namespace phpseclib3\Tests\Unit\Crypt\RSA;
+
 use phpseclib3\Crypt\RSA;
 use phpseclib3\Crypt\RSA\Formats\Keys\PKCS1;
+use phpseclib3\Crypt\RSA\Formats\Keys\PKCS8;
 use phpseclib3\Crypt\RSA\PrivateKey;
 use phpseclib3\Crypt\RSA\PublicKey;
+use phpseclib3\Tests\PhpseclibTestCase;
 
-class Unit_Crypt_RSA_CreateKeyTestRSA extends PhpseclibTestCase
+class CreateKeyTest extends PhpseclibTestCase
 {
     public function testCreateKey()
     {
@@ -66,4 +70,13 @@ class Unit_Crypt_RSA_CreateKeyTestRSA extends PhpseclibTestCase
 
         RSA::useBestEngine();
     }
+
+    public function test3DESPKCS8Encryption()
+    {
+        $key = RSA::createKey(768)
+            ->withPassword('demo')
+            ->toString('PKCS8', ['encryptionAlgorithm' => 'pbeWithSHAAnd3-KeyTripleDES-CBC']);
+        $actual = PKCS8::extractEncryptionAlgorithm($key)['algorithm'];
+        $this->assertSame($actual, 'pbeWithSHAAnd3-KeyTripleDES-CBC');
+    }
 }
